import setuptools

setuptools.setup(
    name="siege-utils",
    version="0.0.1",
    author="Jing Yang",
    packages=setuptools.find_packages(),
    classifiers=["Programming Language :: Python :: 3"]
)
